Index: fetch_configs/webrtc.py |
diff --git a/recipes/webrtc.py b/fetch_configs/webrtc.py |
similarity index 89% |
rename from recipes/webrtc.py |
rename to fetch_configs/webrtc.py |
index e409d2fedd36d5fb04db4c3cdef9f44b7f4e64f8..fbced5efd4d00be99657a9a6b83b94e3b436b1d6 100644 |
--- a/recipes/webrtc.py |
+++ b/fetch_configs/webrtc.py |
@@ -4,13 +4,13 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class WebRTC(recipe_util.Recipe): |
- """Basic Recipe class for WebRTC.""" |
+class WebRTC(config_util.Config): |
+ """Basic Config class for WebRTC.""" |
@staticmethod |
def fetch_spec(props): |